@@ -1,5 +1,5 @@
 import json
-from dataclasses import is_dataclass
+from dataclasses import is_dataclass, asdict
 import textwrap
 import requests
 import os
@@ -21,6 +21,12 @@ class CIDClient:
         'sandbox': 'http://0.0.0.0:5000/graphql',
     }
 
+    __cose_endpoints = {
+        'dev': 'http://cose-ms-dev.coherentdigital.net:8000',
+        'prod': 'http://cose-ms-prod.coherentdigital.net:8000',
+        'sandbox': 'http://0.0.0.0:8080',
+    }
+
     __graphql_endpoint = None
 
     def __init__(self, environment='prod'):
@@ -32,6 +38,7 @@ class CIDClient:
             raise ValueError('Parameter environment must be set to "prod" or "dev" only')
 
         self.__graphql_endpoint = self.__graphql_env_endpoints[environment.lower()]
+        self.__cose_endpoint = self.__cose_endpoints[environment.lower()]
 
     def __check_auth(self):
         if not self.__access_token:
@@ -322,7 +329,6 @@ class CIDClient:
         data = self.__run_gql_query(query)
         return data['data']['extractFullText']
 
-
     def set_archival_copy_url(self, archival_copy_url_input):
         """
         Sets archival copy URL for CID.
@@ -341,3 +347,37 @@ class CIDClient:
                                         'result { status errorMessage }')
         data = self.__run_gql_query(query)
         return data['data']['setArchivalCopyUrl']
+
+    def extract_fragments(self, extract_artifacts_input):
+        """
+        Extract fragments(images, tables, etc) from CID artifact
+        :param extract_artifacts_input: ExtractFragmentsInput object (see mapping_inputs.py)
+        :return: run information
+        """
+        errors = extract_artifacts_input.validate()
+
+        if errors:
+            raise Exception('Error in CID input: {0}'.format(', '.join(errors)))
+
+        data = {
+            "cids": [
+                {
+                    "cid": extract_artifacts_input.cid,
+                },
+            ],
+            "features": extract_artifacts_input.features,
+            "callback": asdict(extract_artifacts_input.callback)
+        }
+
+        response = requests.post(
+            f"{self.__cose_endpoint}/extract",
+            headers={
+                'Content-Type': 'application/json; charset=utf-8',
+                'accept': 'application/json'
+            },
+            json=data
+        )
+
+        response.raise_for_status()
+
+        return response.json()
